@@ -33,8 +33,6 @@ class Device;
 */
 class InsertDialog : public SizeDialogBase
 {
-    Q_OBJECT
-
 public:
     InsertDialog(QWidget* parent, Device& device, Partition& insertedPartition, const Partition& destPartition);
     ~InsertDialog();
@@ -43,8 +41,8 @@ protected:
     const Partition& destPartition() const {
         return m_DestPartition;
     }
-    virtual bool canGrow() const;
-    virtual bool canShrink() const {
+    bool canGrow() const override;
+    bool canShrink() const override {
         return false;
     }
 
