@@ -37,7 +37,7 @@
     @param vgName Volume Group name
     @param pvList List of LVM Physical Volumes used to create Volume Group
 */
-VolumeGroupDialog::VolumeGroupDialog(QWidget* parent, QString& vgName, QList<const Partition*>& pvList) :
+VolumeGroupDialog::VolumeGroupDialog(QWidget* parent, QString& vgName, std::vector<const Partition*>& pvList) :
     QDialog(parent),
     m_DialogWidget(new VolumeGroupWidget(this)),
     m_TargetName(vgName),
@@ -131,7 +131,7 @@ void VolumeGroupDialog::updateSectorInfos()
 
 void VolumeGroupDialog::updateSizeInfos()
 {
-    const QList <const Partition *> checkedPartitions = dialogWidget().listPV().checkedItems();
+    const std::vector<const Partition *> checkedPartitions = dialogWidget().listPV().checkedItems();
     m_TotalSize = 0;
     for (const auto &p : checkedPartitions)
         m_TotalSize += p->capacity() - p->capacity() % (dialogWidget().spinPESize().value() * Capacity::unitFactor(Capacity::Byte, Capacity::MiB)); // subtract space which is too small to hold PE
